@@ -19,7 +19,7 @@ read activate<&5
 if [[ $activate != "ACTIVATED" ]]
 then
 	# start FO
-	echo "PROC:START \"Fiber_Optic\"">&5
+	echo "PROC:FRESHSTART \"Fiber_Optic\"">&5
 	
 	# and wait for activated
 	while [[ $activate != "ACTIVATED" ]]
