@@ -17,7 +17,6 @@ use app\util\SMTUtil;
 
 use app\util\SMTLogger;
 use app\http\SMTContext;
-use app\admin\SMTOtuType;
 
 /**
  * Wrapper for php socket:
@@ -191,7 +190,7 @@ class SMTOtuSocket
      */
     const SOCKET_RESOURCE_TEMPORARILY_UNAVAILABLE = 11;
     
-    const SOCKET_CREATE_LOCK_FILE = "/../../tmp/socket%d.lock";
+    const SOCKET_CREATE_LOCK_FILE = "/../../tmp/socket.lock";
     
     /**
      * Max number of retry in case of connection opening failure
@@ -207,7 +206,7 @@ class SMTOtuSocket
      */
     const PING_TIMEOUT = 10;
     
-    private static $socketLockFile = array();
+    private static $socketLockFile = NULL;
     
     /**
      * Application context
@@ -327,13 +326,13 @@ class SMTOtuSocket
     private function performOpenSocket()
     {
         //synchronize the creation and the opening of the socket on OTU
-        if ( self::acquireLock($this->port) )
+        if ( self::acquireLock() )
         {
             $this->socket = socket_create(AF_INET, SOCK_STREAM, SOL_TCP);
             
             if ( $this->socket === FALSE )
             {
-                self::releaseLock($this->port);
+                self::releaseLock();
                 
                 $this->traceOtuQuery( self::OPEN_SOCKET_ERROR_TAG.SMTSocketException::ERROR_CREATING.": ".$this->socket.self::OPEN_SOCKET_ERROR_TAG_END, SMTLogger::ERROR );
                 
@@ -365,11 +364,11 @@ class SMTOtuSocket
                     }                    
                 }
 
-                self::releaseLock($this->port);
+                self::releaseLock();
             }
             catch( \Exception $e)
             {
-                self::releaseLock($this->port);
+                self::releaseLock();
                 throw $e;
             }
         }
@@ -479,18 +478,18 @@ class SMTOtuSocket
     	if( $this->checkOpened() )
     	{            		    	    
     	    //synchronize the creation and the opening of the socket on OTU
-    	    if ( self::acquireLock($this->port) )
+    	    if ( self::acquireLock() )
     	    {    	    
     	        try 
     	        {
             	    $this->socketWrite( $query);
             	    $esrCode = $this->getInfoEsr( $query, $sleep, $readTimeOut);			
             		$this->processEsr( $query, $esrCode );
-            		self::releaseLock($this->port);
+            		self::releaseLock();
         		}
         		catch( \Exception $e)
         		{
-        		    self::releaseLock($this->port);
+        			self::releaseLock();
         			throw $e;
         		}
     		}
@@ -519,50 +518,33 @@ class SMTOtuSocket
         //check that the socket is opened and if it is not opened, try to re-open it
     	if( $this->checkOpened() )
     	{
-    	    if ( self::acquireLock($this->port) )
-    	    {  
-    	        try
-    	        {
-        		    $this->socketWrite( $query );
-        		    $queryDate = SMTLogger::getDate();
-        		    //$this->traceOtuQuery( self::QUERY_TAG.trim($query).self::QUERY_TAG_END.self::PORT_TAG.$this->port.self::PORT_TAG_END, SMTLogger::DEBUG);
-        		    if ( $this->port == SMTOtuSocket::ISU_PORT )
-        		        {
-        		        $sleep = self::DEFAULT_SLEEP_FOR_ISU;
-        		        }
-        		    usleep ( $sleep ); //sleep 0ms before attempting to read by default
-        		    
-        			$data = $this->receive( $query, $readTimeOut );												
-        			
-        		    //need to wait for ESR of the command
-        		    if ( $data != NULL && $data != '' )
-        		    {
-        		        $esrCode = $this->getInfoEsr( $query, 0, self::TIME_OUT_READING_ESR, FALSE);
-        		    }
-        		    // need only to wait shortly for ESR ( $readTimeOut = 0.1 ): something got wrong
-        		    else
-        		    {
-        		        $esrCode = $this->getInfoEsr($query, 0, 0.1, FALSE);
-        		    }
-        		    
-          		    $this->traceOtuQuery( self::QUERY_TAG.trim($query).self::QUERY_TAG_END.self::PORT_TAG.$this->port.self::PORT_TAG_END.self::ESR_TAG.$esrCode.self::ESR_TAG_END, SMTLogger::INFO, $queryDate, self::RES_TAG.( $data !== NULL? trim( $data ) : "" ).self::RES_TAG_END);
-            		    
-          			$this->processEsr( $query, $esrCode );
-          			self::releaseLock($this->port);
-        	    }
-        	    catch( \Exception $e)
-        	    {
-        	        self::releaseLock($this->port);
-        	        throw $e;
-        	    }
-        	}
-    	}
-    	else
-    	{
-    	    $this->traceOtuQuery( self::OPEN_SOCKET_ERROR_TAG." Failed to acquire lock for query".self::OPEN_SOCKET_ERROR_TAG_END, SMTLogger::ERROR );
-    	    $this->processSocketError( SMTSocketException::ERROR_CREATING, $query );
+		    $this->socketWrite( $query );
+		    $queryDate = SMTLogger::getDate();
+		    //$this->traceOtuQuery( self::QUERY_TAG.trim($query).self::QUERY_TAG_END.self::PORT_TAG.$this->port.self::PORT_TAG_END, SMTLogger::DEBUG);
+		    if ( $this->port == SMTOtuSocket::ISU_PORT )
+		        {
+		        $sleep = self::DEFAULT_SLEEP_FOR_ISU;
+		        }
+		    usleep ( $sleep ); //sleep 0ms before attempting to read by default
+		    
+			$data = $this->receive( $query, $readTimeOut );												
+			
+		    //need to wait for ESR of the command
+		    if ( $data != NULL && $data != '' )
+		    {
+		    	$esrCode = $this->getInfoEsr( $query, 1000, self::TIME_OUT_READING_ESR, FALSE);
+		    }
+		    // need only to wait shortly for ESR ( $readTimeOut = 0.1 ): something got wrong
+		    else
+		    {
+		    	$esrCode = $this->getInfoEsr($query, 1000, 0.1, FALSE);
+		    }
+		    $this->traceOtuQuery( self::QUERY_TAG.trim($query).self::QUERY_TAG_END.self::PORT_TAG.$this->port.self::PORT_TAG_END.self::ESR_TAG.$esrCode.self::ESR_TAG_END, SMTLogger::INFO, $queryDate, self::RES_TAG.( $data !== NULL? trim( $data ) : "" ).self::RES_TAG_END);
+		    
+			$this->processEsr( $query, $esrCode );				
     	}
     	
+    	
     	return ($data !== NULL)? ( $removeQuotes? rtrim( trim( str_replace("\"","", $data ) ), "\n" ): rtrim( trim( $data ), "\n" ) ) : NULL;
     }    
     
@@ -859,17 +841,15 @@ class SMTOtuSocket
      *  
      * @return resource Lock file
      */
-    private static function getSocketLockFile($portNumber)
+    private static function getSocketLockFile()
     {
-        if ( !isset(self::$socketLockFile[$portNumber]) || (self::$socketLockFile[$portNumber] == NULL) )
+    	if ( self::$socketLockFile == NULL )
     	{
-    	    $fileName = sprintf(self::SOCKET_CREATE_LOCK_FILE, $portNumber);
-    	    //SMTLogger::getInstance()->trace($fileName);
-    	    $handle = fopen( __DIR__.$fileName, "w+");
+    		$handle = fopen( __DIR__.self::SOCKET_CREATE_LOCK_FILE, "w+");
     		 
-    	    self::$socketLockFile[$portNumber] = ( $handle != FALSE)? $handle : NULL;
+    		self::$socketLockFile = ( $handle != FALSE)? $handle : NULL;
     	}
-    	return self::$socketLockFile[$portNumber];
+    	return self::$socketLockFile;
     }    
     
     /**
@@ -894,14 +874,14 @@ class SMTOtuSocket
     		try
     		{
     			//synchronize the creation and the opening of the socket on OTU
-    		    if ( self::acquireLock($port) )
+    			if ( self::acquireLock() )
     			{
     			    // AF_INET = access to OTU application on local loop: use only IPv4 Internet based protocols
     				$socket = socket_create(AF_INET, SOCK_STREAM, SOL_TCP);
     	
     				if ( $socket === FALSE )
     				{
-    				    self::releaseLock($port);
+   				    	self::releaseLock();
     					$socketErrorTrace = socket_strerror(socket_last_error());
     					throw new SMTSocketException( SMTSocketException::ERROR_CREATING, $socketErrorTrace );
     				}
@@ -926,13 +906,13 @@ class SMTOtuSocket
     						throw new SMTSocketException( SMTSocketException::ERROR_OPENING, $socketErrorTrace );
     					}
     				}
-    				self::releaseLock($port);
+    				self::releaseLock();
     			}
     		}
     		catch (\Exception $e)
     		{
     			$success = FALSE;
-    			self::releaseLock($port);
+    			self::releaseLock();
     			if ( $retryCount >= $maxRetryCount )
     			{    			    
     				throw $e;
@@ -951,7 +931,7 @@ class SMTOtuSocket
      * Creation of sockets must be synchronized 
      * @return TRUE if lock could be acquired
      */
-    static function acquireLock($portNumber)
+    static function acquireLock()
     {
         $retries = 0;
         $max_retries = 60;
@@ -964,7 +944,7 @@ class SMTOtuSocket
         		usleep( 500 * ( $retries*$retries ) );
         	}
         	$retries += 1;
-        } while ( (!flock(self::getSocketLockFile($portNumber), LOCK_EX, $eWouldBlock) || $eWouldBlock ) && $retries <= $max_retries);
+        } while ( (!flock(self::getSocketLockFile(), LOCK_EX, $eWouldBlock) || $eWouldBlock ) && $retries <= $max_retries);
         
         return ($retries < $max_retries);        
     }
@@ -973,9 +953,9 @@ class SMTOtuSocket
      * Release socket creation lock file
      * @return TRUE if lock could be released
      */
-    static function releaseLock($portNumber)
+    static function releaseLock()
     {
-        return (isset(self::$socketLockFile[$portNumber]) && self::$socketLockFile[$portNumber] != NULL)? flock( self::$socketLockFile[$portNumber], LOCK_UN ) : TRUE;
+        return (isset(self::$socketLockFile) && self::$socketLockFile != NULL)? flock( self::$socketLockFile, LOCK_UN ) : TRUE;
     }
 }
 
