@@ -364,7 +364,7 @@ class SMTEthernet extends SMTServiceHelper
                 $dns = $ipv6->getDns();
                 
                 if ( strlen( $dns ) <= 0 ) { $dns = "::"; }
-                if ( SMTOtuType::isOTH()  || SMTOtuType::isFTH7K() )
+                if ( SMTOtuType::isOTH()  || SMTOtuType::isFTH7K() || SMTOtuType::isCOtu() )
                 {
                     $this->send( sprintf( SMTOtuApi::CMD_set_ipv6_prefix, $interface, $ipv6->getSubnetPrefixLength() ) );
                 }
