@@ -8,7 +8,7 @@ ROOT_ACCESS="$(fw_printenv root_access | cut -f2 -d= )"
 ENH="$(fw_printenv Enhanced_Security | cut -f2 -d= )"
 SMARTOTUGUESTUSER="smartotuguest"
 
-create_smartotuguest_user () {
+function create_smartotuguest_user () {
     #  Create smartotuguest usergroup and add smartotuguest user into the group
     #    No user login shell and no home directory for the smartotuguset user 
     [ -z $(grep smartotuguest /etc/group) ] && groupadd smartotuguest
@@ -18,7 +18,7 @@ create_smartotuguest_user () {
     # [ -z $(grep "\:smartotuguest$" /etc/aliases) ] &&  echo "guest:smartotuguest" >> /etc/aliases
 }
 
-delete_smartotugguest_user () {
+function delete_smartotuguest_user () {
     #  remove smartotuguest
     userdel -f smartotuguest > /dev/null 2>&1
 
@@ -26,6 +26,30 @@ delete_smartotugguest_user () {
     [ ! -z $(grep "\:smartotuguest$" /etc/aliases) ] &&  sed -i '/:smartotuguest$/d' /etc/aliases
 }
 
+function secuser_disable() {
+    # Kill all processes opened by secuser
+    pkill -SIGKILL -u secuser
+    # Lock the user
+    usermod -L secuser
+    # Expire the user account
+    chage -E0 secuser
+    # Do not allow shell access
+    usermod -s /sbin/nologin secuser
+    # Add a comment to the user
+    usermod -c "disabled" secuser
+}
+
+function secuser_enable() {
+    # Remove the comment from the user
+    usermod -c "" secuser
+    # Allow shell access
+    usermod -s /bin/bash secuser
+    # Un-expire the user account
+    chage -I -1 -m 0 -M 99999 -E -1 secuser
+    # Unlock the user
+    usermod -U secuser
+}
+
 if [[ "$ENH" == "true" ]] ; then
     # backup user to removed
     if [ ! -s ${BACKUP_FILE_PASSWD} ] ; then
@@ -42,11 +66,8 @@ if [[ "$ENH" == "true" ]] ; then
         [ "${i}" == "$SMARTOTUGUESTUSER" ] && [ ! -z $(grep "\:smartotuguest$" /etc/aliases) ] &&  sed -i '/:smartotuguest$/d' /etc/aliases
     done
     if [[ "${ROOT_ACCESS}" != "true" ]] ; then
-        id secuser 2>&1 > /dev/null
-        if [[ $? -ne 0 ]] ; then
-            # Recreate secuser : needed for onmsi if no root access license
-            /usr/sbin/create_secuser.sh
-        fi
+        # Enable secuser if it is not already enabled - needed for onmsi if "no root access" license
+        [ "$(passwd -S secuser | cut -d " " -f2)" != "P" ] && secuser_enable
 
         id smartotuguest 2>&1 > /dev/null
         if [[ $? -ne 0 ]] ; then
@@ -54,16 +75,13 @@ if [[ "$ENH" == "true" ]] ; then
             create_smartotuguest_user
         fi
     else
-        # root access license : remove secuser
-        id secuser 2>&1 > /dev/null
-        if [[ $? -eq 0 ]] ; then
-            userdel -f secuser > /dev/null 2>&1
-        fi
+        # Disable secuser if it is not already disabled - only if no "no root access" license is installed
+        [ "$(passwd -S secuser | cut -d " " -f2)" != "L" ] && secuser_disable
 
         # root access license : remove smartotuguest
         id smartotuguest 2>&1 > /dev/null
         if [[ $? -eq 0 ]] ; then
-            delete_smartotugguest_user
+            delete_smartotuguest_user
         fi
     fi
 else
@@ -74,32 +92,28 @@ else
         rm ${BACKUP_FILE_PASSWD}
         rm ${BACKUP_FILE_SHADOW}
     fi
-    # if not root_access license, we need secuser, ensure that
-#    if [[ "${ROOT_ACCESS}" != "true" ]] ; then
-        id secuser 2>&1 > /dev/null
-        if [[ $? -ne 0 ]] ; then
-            # Recreate secuser
-            /usr/sbin/create_secuser.sh
-        fi
 
-        id smartotuguest 2>&1 > /dev/null
-        if [[ $? -ne 0 ]] ; then
-            # Recreate smartotu
-            create_smartotuguest_user
-            # /usr/sbin/create_smartotu_guest.sh
-        fi
-#    fi
+    # Enable secuser if it is not already enabled
+    [ "$(passwd -S secuser | cut -d " " -f2)" != "P" ] && secuser_enable
+
+    id smartotuguest 2>&1 > /dev/null
+    if [[ $? -ne 0 ]] ; then
+        # Recreate smartotu
+        create_smartotuguest_user
+    fi
 fi
 
-if [ `grep smartotu: /etc/group | wc -l` == 0 ];
+if [ $(grep smartotu: /etc/group | wc -l) == 0 ];
 then
    groupadd smartotu
 fi
-if [ `grep smartotu: /etc/shadow | wc -l` == 0 ];
+
+if [ $(grep smartotu: /etc/shadow | wc -l) == 0 ];
 then
    useradd -d /usr/share/apache2/htdocs -p \\\$1\\\$lyAU2uvD\\\$He7fcR4c8rwL6ImTs0sR3/ -r -s /bin/bash smartotu -g smartotu
 fi
-if [ `grep ntp: /etc/shadow | wc -l` == 0 ];
+
+if [ $(grep ntp: /etc/shadow | wc -l) == 0 ];
 then
    useradd --system --home-dir /var/lib/ntp --no-create-home --shell /bin/false -g 993 ntp
 fi
