@@ -524,7 +524,7 @@ def t_tacb_prog_flash(cmd):
 
     print("Binary file path: %s" %(bin_file_path))
 
-    p = subprocess.Popen("advisordff tacb -sf %s %s" % (Hetnet_Module, bin_file_path), shell=True, stdin=subprocess.PIPE,stdout=subprocess.PIPE, stderr=subprocess.STDOUT, close_fds=True)
+    p = subprocess.Popen("fiberprogfpga tacb -sf %s %s" % (Hetnet_Module, bin_file_path), shell=True, stdin=subprocess.PIPE,stdout=subprocess.PIPE, stderr=subprocess.STDOUT, close_fds=True)
     p.wait()
     err = p.returncode
     print(err)
